=======
ec2ools
=======
.. image:: https://img.shields.io/pypi/v/ec2ools.svg
        :target: https://pypi.python.org/pypi/ec2ools

.. image:: https://img.shields.io/travis/ibejohn818/ec2ools.svg
        :target: https://travis-ci.org/ibejohn818/ec2ools

.. image:: https://readthedocs.org/projects/ec2ools/badge/?version=latest
        :target: https://ec2ools.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/ibejohn818/ec2ools/shield.svg
     :target: https://pyup.io/repos/github/ibejohn818/ec2ools/
     :alt: Updates


`ec2ools` is a cli of useful tools to use on an ec2 instance to aid in management and automation.   
Some examples of functionality are:
- Am I the oldest instance in an ASG (IE: to determine a master node)
- Attach an elastic-ip to myself by alloc-id
- Place myself into/out-of standby in my ASG & detach/attach from/to LB for deployments (IE: Codedeploy)
- etc...

2019-08-29
The cli is still in development and only a few functions are currently released.  
My intentions are to start work on some of these tools in the not to distant future.





Utilities to manage ec2 instances and asg's


* Free software: MIT license
* Documentation: https://ec2ools.readthedocs.io.